import React, {Component} from "react";
import {ActionSheet, Modal} from 'antd-mobile';
import Lightbox from "react-images";
import Album from "./Album/Album";
import AttUtil from "./AttUtil/AttUtil";
import Camera from "./Camera/Camera";
import Video from "./Video/Video";
import Audio from "./Audio/Audio";
import "./Attachments.scss";
import {audioFlagIcon, audioPauseIcon, audioPlayIcon, moreIcon} from "./images/icon";
import Sign from "./Sign/Sign";
import SignCanvas from "./Sign/SignCanvas";
import PropTypes from "prop-types";
import ListView from "../ListView";

class Attachments extends Component {

  state = {
    isOpen: false,
    currentImage: 0,
    pic: [],
    video: '',
    videoPath: '',
    audio: '',
    audioPath: '',
    isSigning: false,
    sign: '',
    star: 0
  };

  componentWillMount() {
    const {pictures, videos, audios, signs, stars} = this.props;
    if (pictures && pictures.length) {
      this.setState({
        pic: pictures
      })
    }
    if (AttUtil.isFilledArray(videos)) {
      if (AttUtil.isBase64Data(videos[0])) {
        this.setState({
          video: videos[0],
        })
      } else {
        this.setState({
          videoPath: videos[0]
        })
      }
    }
    if (AttUtil.isFilledArray(audios)) {
      if (AttUtil.isBase64Data(audios[0])) {
        this.setState({
          audio: audios[0],
        })
      } else {
        this.setState({
          audioPath: audios[0]
        })
      }
    }
    if (signs) {
      this.setState({
        sign: signs
      })
    }
    if (stars) {
      this.setState({
        star: stars
      })
    }
  }

  //获取图片
  getPic = (picData) => {
    const {pic} = this.state;
    const newPic = [...pic];
    newPic.push(picData);
    this.setState({
      pic: newPic
    });
  };

  //获取录像
  getVideo = (videoData, videoPath) => {
    this.setState({
      video: videoData,
      videoPath
    })
  };

  //获取录像
  getAudio = (audioData, audioPath) => {
    this.setState({
      audio: audioData,
      audioPath
    })
  };

  //获取签字
  getSign = (isSigning, signData, starData) => {
    this.setState({
      isSigning
    });
    if(signData){
      this.setState({
        sign: signData
      })
    }
    if(starData){
      this.setState({
        star: starData
      })
    }
  };

  //获取画布
  getCanvas = () => {
    this.setState({
      isSigning: true,
    })
  };

  //显示更多sheet
  showMoreSheet = () => {
    const {useVideo, useAudio, useSign, more} = this.props;
    let moreList = [];
    useVideo ? moreList.push({icon: <Video onClick={this.getVideo}/>, title: '视频'}) : '';
    useAudio ? moreList.push({icon: <Audio onClick={this.getAudio}/>, title: '录音'}) : '';
    useSign ? moreList.push({icon: <Sign onClick={this.getCanvas}/>, title: '签字'}) : '';
    if (AttUtil.isFilledArray(more)) {
      more.map((item) => {
        moreList.push(item)
      })
    }
    ActionSheet.showShareActionSheetWithOptions({
      options: moreList,
    })
  };

  //预览图展示区
  showPrePicNode = () => {
    const {pic, currentImage, isOpen} = this.state;
    const gotoPrevious = () => {
      this.setState({
        currentImage: this.state.currentImage - 1,
      });
    };
    const gotoNext = () => {
      this.setState({
        currentImage: this.state.currentImage + 1,
      });
    };
    const closeLightbox = () => {
      this.setState({
        isOpen: false,
      });
    };
    const prePic = pic.map((item) => {
      return {src: AttUtil.PIC_PREFIX + item}
    });
    return <Lightbox
      images={prePic}
      currentImage={currentImage}
      isOpen={isOpen}
      onClickPrev={() => gotoPrevious()}
      onClickNext={() => gotoNext()}
      onClose={() => closeLightbox()}
    />
  };

  //图片展示区
  showPicNode = () => {
    const {pic} = this.state;
    const {isModify, pictures} = this.props;
    const canDelete = !pictures || isModify;
    //删除图片
    const deletePic = (index) => {
      let newPic = [...pic];
      newPic.splice(index, 1);
      this.setState({
        pic: newPic
      });
    };
    //打开图片预览图
    const openPreviewPic = (index) => {
      const {isOpen} = this.state;
      this.setState({
        isOpen: !isOpen,
        currentImage: index
      });
    };
    let src = [];
    return pic.map(function (data, index) {
      src.push({src: AttUtil.isBase64Data(data) ? AttUtil.PIC_PREFIX + data : data});
      return <div className='zk_attachments_pic' key={'pic-' + index}>
        <img src={AttUtil.PIC_PREFIX + data} onClick={() => {
          openPreviewPic(index);
        }} alt={'pic'}/>
        {canDelete ? <a className='zk_attachments_del' onClick={() => {
          deletePic(index)
        }}/> : ''}
      </div>
    })
  };

  //录像展示区
  showVideoNode = () => {
    const {videoPath, video} = this.state;
    const {isModify, videos} = this.props;
    const canDelete = !AttUtil.isFilledArray(videos) || isModify;
    const deleteVideo = () => {
      this.setState({
        video: '',
        videoPath: ''
      })
    };
    const src = videoPath ? videoPath : AttUtil.VIDEO_PREFIX + video;
    return video || videoPath ?
      <div className='zk_attachments_video'>
        <video src={src} controls preload="auto"/>
        {canDelete ? <a className='zk_attachments_del' onClick={() => {
          deleteVideo();
        }}/> : ''}
      </div>
      : '';
  };

  //录音展示区
  showAudioNode = () => {
    const {audioPath, audio, isPlay} = this.state;
    const {isModify, audios} = this.props;
    const canDelete = !AttUtil.isFilledArray(audios) || isModify;
    const playAudio = () => {
      const media = new Media(audioPath, () => {
        }, (e) => {
          console.log('获取音频失败', e);
          this.setState({
            isPlay: false
          })
        },
        (mediaStatus) => {
          if (mediaStatus === AttUtil.MEDIA_RUNNING) {
            this.setState({
              isPlay: true
            })
          } else if (mediaStatus === AttUtil.MEDIA_PAUSED || mediaStatus === AttUtil.MEDIA_STOPPED) {
            this.setState({
              isPlay: false
            })
          }
        });
      isPlay ? media.pause() : media.play();
    };
    const deleteAudio = () => {
      Modal.alert('', '确定要删除音频?', [
        {text: '取消'},
        {
          text: '确定', onPress: () => {
            this.setState({
              audio: '',
              audioPath: ''
            })
          }
        },
      ]);
    };
    return audio || audioPath ?
      <div className={'zk_attachments_audio'}
           onClick={() => {
             playAudio();
           }}>
        <img className={'zk_attachments_audio_flag'} src={audioFlagIcon} alt={'flag'}/>
        <img className={'zk_attachments_audio_play'} src={isPlay ? audioPauseIcon : audioPlayIcon} alt={'play'}/>
        {canDelete ? <a className={'zk_attachments_del'} onClick={(e) => {
          e.stopPropagation();
          deleteAudio();
        }}/> : ''}
      </div> : ''
  };

  //签字展示区
  showSignNode = () => {
    const {sign} = this.state;
    const {signs, isModify} = this.props;
    const canDelete = !signs || isModify;
    const deleteSign = () => {
      this.setState({
        sign: '',
        star: 0
      })
    };
    return sign ? <div className='zk_attachments_pic'>
      <img src={AttUtil.PIC_PREFIX + sign} onClick={() => {
        this.getCanvas()
      }} alt={'sign'}/>
      {canDelete ? <a className='zk_attachments_del' onClick={() => {
        deleteSign()
      }}/> : ''}
    </div> : ''
  };

  componentDidUpdate(prevProps, prevState, snapshot) {
    const {pic, video, videoPath, audio, audioPath, sign, star} = this.state;
    const hasNewPic = prevState.pic.length !== pic.length;
    const hasNewVideo = prevState.video !== video || prevState.videoPath !== videoPath;
    const hasNewAudio = prevState.audio !== audio || prevState.audioPath !== audioPath;
    const hasNewSign = prevState.sign !== sign || prevState.star !== star;
    if (hasNewPic || hasNewVideo || hasNewAudio || hasNewSign) {
      const {onChange} = this.props;
      let attachments = {
        pictures: pic,
        videos: video,
        videoPaths: videoPath,
        audios: audio,
        audioPaths: audioPath,
        signs: sign,
        stars: star
      };
      onChange ? onChange(attachments) : '';
    }
  }

  render() {
    const {pic, video, videoPath, audio, audioPath, isSigning, sign} = this.state;
    const {useCamera, useAlbum, useVideo, more, useAudio, picMaxNum, useStar, stars, signs} = this.props;
    const hasAttachment = AttUtil.isFilledArray(pic) || video || videoPath || audio || audioPath || sign;
    const hasMore = useAudio || useVideo || more;
    return <div>
      {this.showPrePicNode()}
      <SignCanvas useStar={useStar} isSigning={isSigning} onChange={this.getSign} stars={stars} signs={signs}/>
      <div className={hasAttachment ? 'zk_attachments_area' : ''}>
        {this.showVideoNode()}
        {this.showPicNode()}
        {this.showAudioNode()}
        {this.showSignNode()}
      </div>
      <div className={'zk_attachments_btn'}>
        {useAlbum ? <Album onClick={this.getPic} picNum={pic.length} picMaxNum={picMaxNum}/> : ''}
        {useCamera ? <Camera onClick={this.getPic} picNum={pic.length} picMaxNum={picMaxNum}/> : ''}
        {hasMore ? <img className={'zk_attachments_more'} onClick={() => {
          this.showMoreSheet()
        }} src={moreIcon} alt={'更多'}/> : ''}
      </div>
    </div>
  }
}

Attachments.propTypes = {
  // 使用拍摄功能
  useCamera: PropTypes.bool,
  // 使用相册功能
  useAlbum: PropTypes.bool,
  // 使用录像功能
  useVideo: PropTypes.bool,
  // 使用录音功能
  useAudio: PropTypes.bool,
  // 使用签字功能
  useSign: PropTypes.bool,
  // 使用客户评价功能（在useSign为true时生效）
  useStar: PropTypes.bool,
  // 扩展其他类型附件时使用，传入一个元素为img标签的数组，该数组中的img会被放入更多按钮的sheet中
  more: PropTypes.array,
  // 图片展示（支持base64码或图片路径）
  pictures: PropTypes.array,
  // 视频展示（支持base64码或视频路径）
  videos: PropTypes.array,
  // 音频展示（支持音频路径）
  audios: PropTypes.array,
  // 签字展示（支持base64码或图片路径）
  signs: PropTypes.array,
  // 返回所有附件数据的回调，获取组件内数据
  onChange: PropTypes.func,
  //是否可以修改照片（用于既提供图片又可拍照的场景）
  isModify: PropTypes.bool,
};

export default Attachments;
