/**
 * 柱状图组件
 */
import React, {Component} from 'react'
import PropTypes from 'prop-types'
import ReactEcharts from 'echarts-for-react';

class Bar extends Component {
  loading = null;
  time = 3000;
  textColor = '#2983c7';
  onChartReady = (chart) => {
    this.loading = setTimeout(function () {
      chart.hideLoading();
    }, this.time);
    console.log('echarts is ready');
  };
  getOption = () => {
    return {
      title: {
        text: this.props.title,
        x: 'center',
        textStyle: {
          color: this.textColor,
          fontWeight: 'normal'
        }
      },
      tooltip: {
        trigger: 'axis',
        axisPointer: {            // 坐标轴指示器，坐标轴触发有效
          type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
        }
      },
      legend: {
        data: this.props.barDataArr.map((item) => {
          return item.name
        }),
        bottom: 0,
        right: 'auto',
      },
      grid: {
        left: '3%',
        right: '4%',
        top: '14%',
        containLabel: true
      },
      xAxis: [{
        data: this.props.xDataArr,
        show: this.props.xDataArr.length > 0,
        // axisLabel:{
        //   interval:0 //强制显示所有的横坐标信息
        // }
      }],
      yAxis: [{
        type: 'value',
        show: this.props.xDataArr.length > 0,
      }],
      series: this.seriesData(this.props.barDataArr)
    };
  };
  getLoadingOption = () => {
    return {
      text: '加载中...',
      color: '#000',
      textColor: '#000',
      maskColor: '#fff',
    };
  };
  handleData = (data) => {
    let body = '';
    if (data.length === 0) {
      body = <div className='zk_div-echars_nodata' style={{display: this.state.display}}>无数据</div>;
    }
    return body;
  };
  seriesData = (barDataArr) => {
    let seriesArr = [];
    for (let i = 0; i < barDataArr.length; i++) {
      let seriesArrItem = {
        name: barDataArr[i].name,
        type: 'bar',
        stack: this.props.stack ? '总量' : '',
        data: barDataArr[i].data,
        areaStyle: this.props.stack ? {} : null
      };
      seriesArr.push(seriesArrItem)
    }
    return seriesArr;
  }

  constructor(props) {
    super(props);
    this.state = {
      showLoading: true
    }
  }

  componentWillUnmount() {
    clearTimeout(this.loading);
  }

  componentWillReceiveProps(nextProps) {
    this.onChartReady(this.echarts_react.getEchartsInstance());
    this.setState({
      display: 'block',
      showLoading: false
    });
  }

  render() {
    const {xDataArr} = this.props;
    let body = this.handleData(xDataArr);
    return (
      <div style={{position: 'relative'}}>
        <ReactEcharts
          ref={(e) => {
            this.echarts_react = e;
          }}
          option={this.getOption()}
          loadingOption={this.getLoadingOption()}
          onChartReady={this.onChartReady}
          showLoading={this.state.showLoading}
          className={this.props.className}
        />
        {body}
      </div>
    )
  }
}

Bar.propTypes = {
  // 数据
  xDataArr: PropTypes.array.isRequired,
  barDataArr: PropTypes.array.isRequired,
  // 标题
  title: PropTypes.string,
  // 是否是堆叠效果
  stack: PropTypes.bool,
  // 容器样式类名称
  className: PropTypes.string,
};
export default Bar;
