//竖直或者水平布局
//父级属性（具体可参考ant中Flex组件的参数）：
//itemsData:嵌入的子级数据数组(必需)
//direction：项目定位方向，默认row（竖直排列）
//height : 容器高度，可以是数值、字符串，默认100%
//子级属性（即itemsData中可传入的参数）：
//flex:项目在容器中占的比例，默认1（平均分配）
//autoHeight:项目高度根据内容而定，此时flex必须设置成‘none’才生效（须在父级direction为column时使用）
//autoWidth:项目宽度根据内容而定，此时flex必须设置成‘none’才生效（须在父级direction为row时使用）
//backgroundColor:项目自身背景颜色
//autoScroll:是否可滚动，默认false
//html: 嵌入的代码(必需)

import React, {Component} from 'react'
import {withRouter} from 'react-router'
import {Flex} from 'antd-mobile'

class Box extends Component {
  loadIndexData = (data, index) => {
    let isScroll = data.autoScroll ? 'auto' : 'hidden';
    let isAutoHeight = data.autoHeight ? 'auto' : '100%';
    let isAutoWidth = data.autoWidth ? 'auto' : '100%';
    return (
      <div key={`flex-${index}`} style={{
        height: isAutoHeight,
        width: isAutoWidth,
        flex: data.flex || 1,
        overflow: isScroll,
        backgroundColor: data.backgroundColor || '#f2f2f2'

      }}>
        {data.html}
      </div>
    )
  };

  constructor(props) {
    super(props);
  }

  render() {
    //父级
    const containerDirection = this.props.direction || 'row';
    const containerHeight = this.props.height;
    //子级
    const itemsData = this.props.itemsData;

    return (
      <Flex direction={containerDirection}
            style={{
              height: containerHeight || '100%',
              backgroundColor: '#efefef'
            }}
      >
        {itemsData.map((item, index) => {
          return this.loadIndexData(item, index)
        })}
      </Flex>
    )

  }
}

export default withRouter(Box)
