/**
 * 布局组件
 * 该组件将一级子节点默认进行平均分布，可自定义比例，容器背景、填充和有无分割线
 */
import React, {Component} from 'react'
import PropTypes from 'prop-types'
import {Flex} from 'antd-mobile'
import './styles/FlexLayout.scss'

/**
 * 布局子组件
 */
class Cell extends Component {
  render() {
    let cellClass = this.props.children.props.className || '';
    return (
      <Flex.Item
        style={{...this.props.children.props.style}}
        className={'zk_flexlayout-text_center ' + cellClass}
      >
        {this.props.children}
      </Flex.Item>);
  }
}

/**
 * 布局组件
 */
class FlexLayout extends Component {
  render() {
    const direction = this.props.direction || 'row';
    const wrap = this.props.wrap || 'nowrap';
    const justify = this.props.justify || 'start';
    const align = this.props.align || 'center';
    const alignContent = this.props.alignContent || 'stretch';
    const flexClass = this.props.className || '';
    // 分割线
    let line = '';
    const {hasLine, backgroundColor, padding, children} = this.props;
    if (hasLine) {
      line = direction === 'row' ? ' zk_flexlayout_line_right ' : ' zk_flexlayout_line_bottom ';
    }

    return (
      <Flex
        direction={direction}
        wrap={wrap}
        justify={justify}
        align={align}
        alignContent={alignContent}
        style={{
          backgroundColor: backgroundColor || '#ffffff',
          padding: padding || 0,
        }}
        className={line + flexClass}
      >
        {
          React.Children.map(children, function (child) {
            return <Cell>{child}</Cell>;
          })
        }
      </Flex>
    )
  }

}

FlexLayout.propTypes = {
  // 容器背景
  backgroundColor: PropTypes.string,
  // 容器填充
  padding: PropTypes.string,
  // 项目是否有分割线
  hasLine: PropTypes.bool,
  // 添加的样式类
  className: PropTypes.string
};

export default FlexLayout;
